/////////////////////////////////////////////////////////////////////////////////////
// FILE:    UR_GPIOSetup.h
// TITLE:   Room for user-specific #defines ("Function switches")
// REV:     2009-01-06
// AUTHOR:  Bennet Gedan <bennet.gedan@akasol.de>
/////////////////////////////////////////////////////////////////////////////////////
//
// ASSUMPTIONS:
//
//    none
//
// DESCRIPTION:
//
//    GPIO-Setups for different use-cases. All GPIO-Muxer-Settings are done here
//
//     Function              Use
//    ===========================================================================
//      GPIOSetup_eZdsp()     eZdsp Pinout-Settings for use with Inverter-Adapter 
//
/////////////////////////////////////////////////////////////////////////////////////

#include "DSP28x_Project.h"
#include "UR_GPIOSetup.h"

/*----------------------------------------------------------------
 * void GPIOSetup_eZdsp(void)
 * Bennet Gedan <bennet.gedan@akasol.de>
 *================================================================
 *
 *  DESCRIPTION: GPIOSetup for eZdspBoard -- bg
 *
 *    If eZdspBoard is used with Inverter-Adapter-Board this IO-Settings
 *    should be used. The apropriate MUXER-Settings are done in this
 *    function. (i.e. enabling GPIO5-Muxer as General Purpose IO and as Input)
 *
 *    You'll find this informations in TI information SPRUFB0B 
 *    (System Control and Interrupts) in section 4.2
 *
 *  ARGUMENTS:
 *
 *    void
 *
 *  RETURNS:
 *
 *    void
 *
 *  NOTES:
 *
 *    none
 *
 *--------------------------------------------------------------*/

void GPIOSetup_eZdsp(void) {


      EALLOW;
      //////////////////////////////////////////////////////
      //// PWM Signals
      ////   - see UR_Macros.h for GLUE(A,B)-Macro
      ////   - see UR_Constants_IO.h for GPIO_x replacements
      /////////////////////////////////////////////////////


	  // PWM4A (Pump power setpoint)
	  GLUE(GPXPUD(A),GPIO_PUMP) = 0;    // Enable pullup
	  GLUE(GPXMUXN(A,1),GPIO_PUMP) = 1; // configure as PWM

	  // PWM5A (Fan speed setpoint)
	  GLUE(GPXPUD(A),GPIO_FAN) = 0;    // Enable pullup
	  GLUE(GPXMUXN(A,1),GPIO_FAN) = 1; // configure as PWM

   EDIS;

    /* this comment is just for debugging */
}
