/////////////////////////////////////////////////////////////////////////////////////
// FILE:    UR_PWMs.c
// TITLE:   C-Functions for PWM-Signalling
// REV:     2009-01-08
// AUTHOR:  Bennet Gedan <bennet.gedan@akasol.de>
/////////////////////////////////////////////////////////////////////////////////////
//
// ASSUMPTIONS:
//
//    Used in AKASOL inverter control. 
//    
//    - PWMs are expected at GPIOPins as programmed below
//    - GPIO-Muxer-Settings are correctly set in UR_GPIOSetup.c
//    - AKASOL inverter documentation has been considered
//    
//    Additional PWMs can be programmed here and setup in UR_GPIOSetup.c 
//
// DESCRIPTION:
//
//    C-Functions for PWM-Signalling, set up the PWM ratios
//    - see UR_Macros.h for Preprocessor Macros like GLUE etc.
//    - see UR_Constants_IO.h for GPIO_x replacements
//////////////////////////////////////////////////////////////////////////////////////

#include "DSP28x_Project.h"
#include "UR_PWMs.h"

void setPumpPWM_DutyCycle(unsigned int DutyCycle) 
 {
   GLUE(EPWMREGS_PUMP,CMPA.half.CMPA) = DutyCycle;
   /* GLUE(EPWMREGS_PUMP,EPWMCPMB) = Duty; */
 }

 void setFanPWM_DutyCycle(unsigned int DutyCycle) 
 {
   GLUE(EPWMREGS_FAN,CMPA.half.CMPA) = DutyCycle;
   /* GLUE(EPWMREGS_PUMP,EPWMCPMB) = Duty; */
 }


void setAllPWM_Defaults()
 {

//---------------------------------------------------------------------
//--- Must disable the clock to the ePWM modules if you       
//--- want all ePMW modules synchronized.
//---------------------------------------------------------------------
	asm(" EALLOW");						// Enable EALLOW protected register access
	SysCtrlRegs.PCLKCR0.bit.TBCLKSYNC = 0;
	asm(" EDIS");						// Disable EALLOW protected register access


/*** -------------------- ***/ 

   	GLUE(EPWMREGS_FAN,TBCTL.bit.CTRMODE) = 0x3;		// Disable the timer

	GLUE(EPWMREGS_FAN,TBCTL.all) = 0xC033;			// Configure timer control register
	GLUE(EPWMREGS_FAN,TBCTR) = 0x0000;				// Clear timer counter
	GLUE(EPWMREGS_FAN,TBPRD) = 10000;		// Set timer period
	GLUE(EPWMREGS_FAN,TBPHS.half.TBPHS) = 0x0000;	// Set timer phase

	GLUE(EPWMREGS_FAN,CMPA.half.CMPA) = 28125;	// Set PWM duty cycle
	GLUE(EPWMREGS_FAN,CMPCTL.all) = 0x0002;			// Compare control register

	GLUE(EPWMREGS_FAN,AQCTLA.all) = 0x0060;		// Action-qualifier control register A
	GLUE(EPWMREGS_FAN,AQSFRC.all) = 0x0000;		// Action-qualifier s/w force register

	GLUE(EPWMREGS_FAN,AQCSFRC.all) = 0x0000;		// Action-qualifier continuous s/w force register

	GLUE(EPWMREGS_FAN,DBCTL.bit.OUT_MODE) = 0;	// Deadband disabled
	GLUE(EPWMREGS_FAN,PCCTL.bit.CHPEN) = 0;		// PWM chopper unit disabled
	GLUE(EPWMREGS_FAN,TZCTL.bit.TZA) = 0x3;		// Trip action disabled for output A

	GLUE(EPWMREGS_FAN,TBCTL.bit.CTRMODE) = 0x2;	// Enable the timer in count up/down mode


/*** -------------------------- ***/


	GLUE(EPWMREGS_PUMP,TBCTL.bit.CTRMODE) = 0x3;		// Disable the timer

	GLUE(EPWMREGS_PUMP,TBCTL.all) = 0xC033;			// Configure timer control register

	GLUE(EPWMREGS_PUMP,TBCTR) = 0x0000;				// Clear timer counter
	GLUE(EPWMREGS_PUMP,TBPRD) = 10000;		// Set timer period
	GLUE(EPWMREGS_PUMP,TBPHS.half.TBPHS) = 0x0000;	// Set timer phase

	GLUE(EPWMREGS_PUMP,CMPA.half.CMPA) = 28125;	// Set PWM duty cycle

	GLUE(EPWMREGS_PUMP,CMPCTL.all) = 0x0002;			// Compare control register

	GLUE(EPWMREGS_PUMP,AQCTLA.all) = 0x0060;		// Action-qualifier control register A

	GLUE(EPWMREGS_PUMP,AQSFRC.all) = 0x0000;		// Action-qualifier s/w force register

	GLUE(EPWMREGS_PUMP,AQCSFRC.all) = 0x0000;		// Action-qualifier continuous s/w force register

	GLUE(EPWMREGS_PUMP,DBCTL.bit.OUT_MODE) = 0;	// Deadband disabled
	GLUE(EPWMREGS_PUMP,PCCTL.bit.CHPEN) = 0;		// PWM chopper unit disabled
	GLUE(EPWMREGS_PUMP,TZCTL.bit.TZA) = 0x3;		// Trip action disabled for output A

	GLUE(EPWMREGS_PUMP,TBCTL.bit.CTRMODE) = 0x2;	// Enable the timer in count up/down mode

/*** -------------------------- ***/

//---------------------------------------------------------------------
//--- Enable the clocks to the ePWM module.                   
//--- Note: this should be done after all ePWM modules are configured
//--- to ensure synchronization between the ePWM modules.
//---------------------------------------------------------------------
	asm(" EALLOW");							// Enable EALLOW protected register access
	SysCtrlRegs.PCLKCR0.bit.TBCLKSYNC = 1;	// HSPCLK to ePWM modules enabled
	asm(" EDIS");	

 }

